summaryrefslogtreecommitdiff
path: root/src/modules/m_spanningtree/postcommand.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_spanningtree/postcommand.cpp')
-rw-r--r--src/modules/m_spanningtree/postcommand.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_spanningtree/postcommand.cpp b/src/modules/m_spanningtree/postcommand.cpp
index b08f60925..471bbfcb9 100644
--- a/src/modules/m_spanningtree/postcommand.cpp
+++ b/src/modules/m_spanningtree/postcommand.cpp
@@ -39,10 +39,10 @@ void ModuleSpanningTree::OnPostCommand(const std::string &command, const std::ve
void SpanningTreeUtilities::RouteCommand(TreeServer* origin, const std::string &command, const parameterlist& parameters, User *user)
{
- if (!ServerInstance->IsValidModuleCommand(command, parameters.size(), user))
+ if (!ServerInstance->Parser->IsValidCommand(command, parameters.size(), user))
return;
/* We know it's non-null because IsValidModuleCommand returned true */
Command* thiscmd = ServerInstance->Parser->GetHandler(command);
RouteDescriptor routing = thiscmd->GetRouting(user, parameters);
@@ -39,10 +39,10 @@ void ModuleSpanningTree::OnPostCommand(const std::string &command, const std::ve
return;
- /* We know it's non-null because IsValidModuleCommand returned true */
+ /* We know it's non-null because IsValidCommand returned true */
Command* thiscmd = ServerInstance->Parser->GetHandler(command);
RouteDescriptor routing = thiscmd->GetRouting(user, parameters);